"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = sLine;
/**
 * @function label - makes a Path2D repersenting S-curved line
 * @param {Object} style - css-like style object
 * @param {Number} [style.fromx = 0] - x coordinate of the line start
 * @param {Number} [style.fromy = 0] - y coordinate of the line start
 * @param {Number} [style.tox = 0] - x coordinate of the line end
 * @param {Number} [style.toy = 0] - y coordinate of the line end
 * @returns {Path2D} - S-curved line
 */
/* global Path2D */
function sLine(_ref) {
  var _ref$fromx = _ref.fromx;
  var fromx = _ref$fromx === undefined ? 0 : _ref$fromx;
  var _ref$fromy = _ref.fromy;
  var fromy = _ref$fromy === undefined ? 0 : _ref$fromy;
  var _ref$tox = _ref.tox;
  var tox = _ref$tox === undefined ? 0 : _ref$tox;
  var _ref$toy = _ref.toy;
  var toy = _ref$toy === undefined ? 0 : _ref$toy;

  var path = new Path2D();
  var c = tox - fromx - 20;
  c = c > 0 ? c / 2 : Math.log(Math.pow(-c, 10)) * 10;
  var cp1x = fromx + c;
  var cp2x = tox - c;
  path.moveTo(fromx, fromy);
  path.bezierCurveTo(cp1x, fromy, cp2x, toy, tox, toy);
  return path;
}